from examples.utils.prepare_env import get_api_key
from tonplay.methods import TonPlayApi

client = TonPlayApi(get_api_key())
tonplay_jwt_token = """
eyJhbGciOiJSUzI1NiJ9.eyJzdWIiOiJjY2MyYTJhNDg5NTRmNzQwMGNkNjFmMTc2MjNkZWM3YTE5MzcyNjA5ZGEyZjcwMWMyNzFjM2FmZDg1NWQ4MjkwIiwiaXNUZXN0Ijp0cnVlLCJpc3MiOiJodHRwczpcL1wvb2EudG9ucGxheS5pbyIsImV4cCI6MTY4ODQxMjY4OCwidG9rZW5fdHlwZSI6IkFDVElWRSIsImlhdCI6MTY3OTc3MjY4OCwidGVhbV9rZXkiOiI4cVNlcmthQ3RYIiwiYXV0aG9yaXRpZXMiOlsiUk9MRV9VU0VSIiwiUk9MRV9URVNUX1VTRVIiLCJST0xFX0RFVkVMT1BFUiJdLCJ1c2VybmFtZSI6InNlbnNodV84MDA2Mjk5NiJ9.LrI-K-f1zIQCUEGof6abcIaBvNjr016KE2ciwM_PJ4mhhhxtVOY4NDESgip5zVV-p34MXdY9KsqO4prbSEggJzxrpgpAR3aGENXOFDj7p54t_ctt5BlJnmE802qwKipEVfNC3I6PoUtr6512CO8snULZRytHGO2b5q2Jp-Ap3ZaRErkRmqNj7ocrEGjrNbIRi-b-LjTfaDVlvIzq4RHq2ZHWjdfjHA5IRy-rAmxeVlzHfsWzx5-d2UIcXuMhsl17mtC0yQQlf0sNd0iZSThWl-Y6kB3OH9Th3QCC5cHzasYzyfLSDQaz-gu-DytPE12f3N805HIGnqFbMJzvB8OJUQ
"""

print(
    client.check_tonplay_token(tonplay_jwt_token)
)